@@ -1,5 +1,5 @@
 import os
-import site
+import threading
 from datetime import datetime
 import time
 import tkinter as tk
@@ -7,6 +7,15 @@ import pyperclip
 
 link = ""
 link_time = ""
+link_in_clipboard_flag = False
+
+
+def check_clipboard():
+    global link_in_clipboard_flag
+    while 1:
+        if "zoom.us" in pyperclip.paste():
+            link_in_clipboard_flag = True
+            return
 
 
 def get_text():
@@ -21,7 +30,6 @@ def get_text():
 master = tk.Tk()
 master.title('auto zoom join by snir')
 master.configure(background="#2A3240")
-master.iconbitmap(fr"{site.getsitepackages()[1]}\snirzoom\icon.ico")
 
 ok_button = tk.Button(master, text='OK', command=get_text, width=3, height=1, font=("Consolas", 35))
 ok_button.place(x=850, y=422)
@@ -43,15 +51,28 @@ e1.configure(background="#39455B")
 e2.configure(background="#39455B")
 
 if "zoom.us" in str(pyperclip.paste()):
+    link_in_clipboard_flag = True
     link = pyperclip.paste()
     print("got the link from the clipboard:", link)
     link_detected_label.configure(text="detected link from clipboard")
     e1.delete(0, tk.END)
     e1.insert(0, pyperclip.paste())
 
+if not link_in_clipboard_flag:
+    threading.Thread(target=check_clipboard).start()
+
+while 1:
+    master.update()
+    master.after(10)
+    if link_in_clipboard_flag:
+        link_detected_label.configure(text="detected link from clipboard")
+        e1.delete(0, tk.END)
+        e1.insert(0, pyperclip.paste())
+        break
+
 tk.mainloop()
 
-if not "zoom.us" in link:
+if "zoom.us" not in link:
     print("no valid link provided")
     quit()
 
